@@ -23,7 +23,7 @@ from aliyunsdkccc.endpoint import endpoint_data
 class ListInstancesOfUserRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CCC', '2017-07-05', 'ListInstancesOfUser','CCC')
+		RpcRequest.__init__(self, 'CCC', '2017-07-05', 'ListInstancesOfUser')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
