@@ -23,7 +23,7 @@ from aliyunsdkccc.endpoint import endpoint_data
 class ListSkillGroupsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CCC', '2017-07-05', 'ListSkillGroups','CCC')
+		RpcRequest.__init__(self, 'CCC', '2017-07-05', 'ListSkillGroups')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
